@@ -37,13 +37,14 @@ class Server:
         def sent_split(item: Item):  # 分句
             ret = {
                 'texts': item.texts,
-                'sents': [],
+                'res': [],
                 "status": 0
             }
             try:
-                sents = self._ltp.sent_split(item.texts)
-                ret['sents'] = sents
-            except Exception:
+                res = self._ltp.sent_split(item.texts)
+                ret['res'] = res
+            except Exception as e:
+                print(e)
                 ret['status'] = 1
             return ret
 
@@ -54,7 +55,8 @@ class Server:
             }
             try:
                 self._ltp.add_words(words=words.words, max_window=words.max_window)
-            except Exception:
+            except Exception as e:
+                print(e)
                 ret['status'] = 1
             return ret
 
@@ -63,12 +65,13 @@ class Server:
             ret = {
                 'status': 0,
                 'texts': item.texts,
-                'seg': [],
+                'res': [],
             }
             try:
-                seg, hidden = self._ltp.seg(item.texts)
-                ret['seg'] = seg
-            except Exception:
+                res, hidden = self._ltp.seg(item.texts)
+                ret['res'] = res
+            except Exception as e:
+                print(e)
                 ret['status'] = 1
             return ret
 
@@ -77,15 +80,19 @@ class Server:
             ret = {
                 'status': 0,
                 'texts': item.texts,
-                'seg': [],
-                'pos': []
+                'res': [],
+                'seg': []
             }
             try:
                 seg, hidden = self._ltp.seg(item.texts)
                 res = self._ltp.pos(hidden)
+                tmp = []
+                for seg_sent, pos_sent in zip(seg, res):
+                    tmp.append(tuple(zip(seg_sent, pos_sent)))
+                ret['res'] = tmp
                 ret['seg'] = seg
-                ret['pos'] = res
-            except Exception:
+            except Exception as e:
+                print(e)
                 ret['status'] = 1
             return ret
 
@@ -94,15 +101,22 @@ class Server:
             ret = {
                 'status': 0,
                 'texts': item.texts,
-                'seg': [],
-                'ner': [],
+                'res': [],
+                'seg': []
             }
             try:
                 seg, hidden = self._ltp.seg(item.texts)
                 res = self._ltp.ner(hidden)
+                tmp = []
+                for seg_sent, ner_sent in zip(seg, res):
+                    tmp_item = []
+                    for ner_item in ner_sent:
+                        tmp_item.append((''.join(seg_sent[ner_item[1]:ner_item[2]+1]), ner_item[0], ner_item[1], ner_item[2]))
+                    tmp.append(tmp_item)
+                ret['res'] = tmp
                 ret['seg'] = seg
-                ret['ner'] = res
-            except Exception:
+            except Exception as e:
+                print(e)
                 ret['status'] = 1
             return ret
 
@@ -111,15 +125,24 @@ class Server:
             ret = {
                 'status': 0,
                 'texts': item.texts,
-                'seg': [],
-                'srl': [],
+                'res': [],
+                'seg': []
             }
             try:
                 seg, hidden = self._ltp.seg(item.texts)
                 res = self._ltp.srl(hidden)
+                tmp = []
+                for seg_sent, srl_sent in zip(seg, res):
+                    tmp_item = []
+                    for idx, srl_item in enumerate(srl_sent):
+                        if not srl_item:
+                            continue
+                        tmp_item.append((seg_sent[idx], idx, [(item[0], seg_sent[item[1]: item[2]+1], item[1], item[2]) for item in srl_item]))
+                    tmp.append(tmp_item)
+                ret['res'] = tmp
                 ret['seg'] = seg
-                ret['srl'] = res
-            except Exception:
+            except Exception as e:
+                print(e)
                 ret['status'] = 1
             return ret
 
@@ -128,15 +151,22 @@ class Server:
             ret = {
                 'status': 0,
                 'texts': item.texts,
-                'seg': [],
-                'dep': [],
+                'res': [],
+                'seg': []
             }
             try:
                 seg, hidden = self._ltp.seg(item.texts)
                 res = self._ltp.dep(hidden)
+                tmp = []
+                for seg_sent, dep_sent in zip(seg, res):
+                    tmp_item = []
+                    for dep_item in dep_sent:
+                        tmp_word = seg_sent[dep_item[1] - 1] if dep_item[1] > 0 else "ROOT"
+                        tmp_item.append((dep_item[0], seg_sent[dep_item[0]-1], dep_item[1], tmp_word, dep_item[2]))
+                    tmp.append(tmp_item)
+                ret['res'] = tmp
                 ret['seg'] = seg
-                ret['dep'] = res
-            except Exception:
+            except Exception as e:
                 ret['status'] = 1
             return ret
 
@@ -145,15 +175,23 @@ class Server:
             ret = {
                 'status': 0,
                 'texts': item.texts,
-                'seg': [],
-                'sdp': [],
+                'res': [],
+                'seg': []
             }
             try:
                 seg, hidden = self._ltp.seg(item.texts)
                 res = self._ltp.sdp(hidden)
+                tmp = []
+                for seg_sent, sdp_sent in zip(seg, res):
+                    tmp_item = []
+                    for sdp_item in sdp_sent:
+                        tmp_word = seg_sent[sdp_item[1] - 1] if sdp_item[1] > 0 else "ROOT"
+                        tmp_item.append((sdp_item[0], seg_sent[sdp_item[0]-1], sdp_item[1], tmp_word, sdp_item[2]))
+                    tmp.append(tmp_item)
+                ret['res'] = tmp
                 ret['seg'] = seg
-                ret['sdp'] = res
-            except Exception:
+            except Exception as e:
+                print(e)
                 ret['status'] = 1
             return ret
 
@@ -162,15 +200,23 @@ class Server:
             ret = {
                 'status': 0,
                 'texts': item.texts,
-                'seg': [],
-                'sdpg': [],
+                'res': [],
+                'seg': []
             }
             try:
                 seg, hidden = self._ltp.seg(item.texts)
                 res = self._ltp.sdp(hidden)
+                tmp = []
+                for seg_sent, sdpg_sent in zip(seg, res):
+                    tmp_item = []
+                    for sdpg_item in sdpg_sent:
+                        tmp_word = seg_sent[sdpg_item[1] - 1] if sdpg_item[1] > 0 else "ROOT"
+                        tmp_item.append((sdpg_item[0], seg_sent[sdpg_item[0]-1], sdpg_item[1], tmp_word, sdpg_item[2]))
+                    tmp.append(tmp_item)
+                ret['res'] = tmp
                 ret['seg'] = seg
-                ret['sdpg'] = res
-            except Exception:
+            except Exception as e:
+                print(e)
                 ret['status'] = 1
             return ret
 
